abacusai.api_class.batch_prediction — AbacusAI documentation

# abacusai.api_class.batch_prediction

## Classes

`ApiClass` | Helper class that provides a standard way to create an ABC using
`_ApiClassFactory` | Helper class that provides a standard way to create an ABC using
`BatchPredictionArgs` | An abstract class for Batch Prediction args specific to problem type.
`ForecastingBatchPredictionArgs` | Batch Prediction Config for the FORECASTING problem type
`NamedEntityExtractionBatchPredictionArgs` | Batch Prediction Config for the NAMED_ENTITY_EXTRACTION problem type
`PersonalizationBatchPredictionArgs` | Batch Prediction Config for the PERSONALIZATION problem type
`PredictiveModelingBatchPredictionArgs` | Batch Prediction Config for the PREDICTIVE_MODELING problem type
`PretrainedModelsBatchPredictionArgs` | Batch Prediction Config for the PRETRAINED_MODELS problem type
`SentenceBoundaryDetectionBatchPredictionArgs` | Batch Prediction Config for the SENTENCE_BOUNDARY_DETECTION problem type
`ThemeAnalysisBatchPredictionArgs` | Batch Prediction Config for the THEME_ANALYSIS problem type
`ChatLLMBatchPredictionArgs` | Batch Prediction Config for the ChatLLM problem type
`TrainablePlugAndPlayBatchPredictionArgs` | Batch Prediction Config for the TrainablePlugAndPlay problem type
`_BatchPredictionArgsFactory` | Helper class that provides a standard way to create an ABC using

## Module Contents

class abacusai.api_class.batch_prediction.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  __post_init__()
  classmethod _get_builder()
  __str__()

    Return str(self).

  _repr_html_()
  __getitem__(item)
    Parameters:

      item (str)

  __setitem__(item, value)
    Parameters:

      - item (str)

      - value (Any)

  _unset_item(item)
    Parameters:

      item (str)

  get(item, default=None)
    Parameters:

      - item (str)

      - default (Any)

  pop(item, default=NotImplemented)
    Parameters:

      - item (str)

      - default (Any)

  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict)

class abacusai.api_class.batch_prediction._ApiClassFactory

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class = None
  config_class_key = None
  config_class_map
  classmethod from_dict(config)
    Parameters:

      config (dict)

    Return type:

      ApiClass

class abacusai.api_class.batch_prediction.BatchPredictionArgs

  Bases: `abacusai.api_class.abstract.ApiClass`

  An abstract class for Batch Prediction args specific to problem type.

  _support_kwargs: bool
  kwargs: dict
  problem_type: abacusai.api_class.enums.ProblemType
  classmethod _get_builder()

class abacusai.api_class.batch_prediction.ForecastingBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the FORECASTING problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation

    - predictions_start_date (str) – The start date for predictions. Accepts timestamp integers and strings in many standard formats such as YYYY-MM-DD, YYYY-MM-DD HH:MM:SS, or YYYY-MM-DDTHH:MM:SS. If not specified, the prediction start date will be automatically defined.

    - use_prediction_offset (bool) – If True, use prediction offset.

    - start_date_offset (int) – Sets prediction start date as this offset relative to the prediction start date.

    - forecasting_horizon (int) – The number of timestamps to predict in the future. Range: [1, 1000].

    - item_attributes_to_include_in_the_result (list) – List of columns to include in the prediction output.

    - explain_predictions (bool) – If True, calculates explanations for the forecasted values along with predictions.

    - create_monitor (bool) – Controls whether to automatically create a monitor to calculate the drift each time the batch prediction is run. Defaults to true if not specified.

  for_eval: bool
  predictions_start_date: str
  use_prediction_offset: bool
  start_date_offset: int
  forecasting_horizon: int
  item_attributes_to_include_in_the_result: list
  explain_predictions: bool
  create_monitor: bool
  __post_init__()

class abacusai.api_class.batch_prediction.NamedEntityExtractionBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the NAMED_ENTITY_EXTRACTION problem type

  Parameters:

    for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

  for_eval: bool
  __post_init__()

class abacusai.api_class.batch_prediction.PersonalizationBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the PERSONALIZATION problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

    - number_of_items (int) – Number of items to recommend.

    - item_attributes_to_include_in_the_result (list) – List of columns to include in the prediction output.

    - score_field (str) – If specified, relative item scores will be returned using a field with this name

  for_eval: bool
  number_of_items: int
  item_attributes_to_include_in_the_result: list
  score_field: str
  __post_init__()

class abacusai.api_class.batch_prediction.PredictiveModelingBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the PREDICTIVE_MODELING problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

    - explainer_type (enums.ExplainerType) – The type of explainer to use to generate explanations on the batch prediction.

    - number_of_samples_to_use_for_explainer (int) – Number Of Samples To Use For Kernel Explainer.

    - include_multi_class_explanations (bool) – If True, Includes explanations for all classes in multi-class classification.

    - features_considered_constant_for_explanations (str) – Comma separate list of fields to treat as constant in SHAP explanations.

    - importance_of_records_in_nested_columns (str) – Returns importance of each index in the specified nested column instead of SHAP column explanations.

    - explanation_filter_lower_bound (float) – If set explanations will be limited to predictions above this value, Range: [0, 1].

    - explanation_filter_upper_bound (float) – If set explanations will be limited to predictions below this value, Range: [0, 1].

    - explanation_filter_label (str) – For classification problems specifies the label to which the explanation bounds are applied.

    - output_columns (list) – A list of column names to include in the prediction result.

    - explain_predictions (bool) – If True, calculates explanations for the predicted values along with predictions.

    - create_monitor (bool) – Controls whether to automatically create a monitor to calculate the drift each time the batch prediction is run. Defaults to true if not specified.

  for_eval: bool
  explainer_type: abacusai.api_class.enums.ExplainerType
  number_of_samples_to_use_for_explainer: int
  include_multi_class_explanations: bool
  features_considered_constant_for_explanations: str
  importance_of_records_in_nested_columns: str
  explanation_filter_lower_bound: float
  explanation_filter_upper_bound: float
  explanation_filter_label: str
  output_columns: list
  explain_predictions: bool
  create_monitor: bool
  __post_init__()

class abacusai.api_class.batch_prediction.PretrainedModelsBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the PRETRAINED_MODELS problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

    - files_output_location_prefix (str) – The output location prefix for the files.

    - channel_id_to_label_map (str) – JSON string for the map from channel ids to their labels.

  for_eval: bool
  files_output_location_prefix: str
  channel_id_to_label_map: str
  __post_init__()

class abacusai.api_class.batch_prediction.SentenceBoundaryDetectionBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the SENTENCE_BOUNDARY_DETECTION problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation

    - explode_output (bool) – Explode data so there is one sentence per row.

  for_eval: bool
  explode_output: bool
  __post_init__()

class abacusai.api_class.batch_prediction.ThemeAnalysisBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the THEME_ANALYSIS problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

    - analysis_frequency (str) – The length of each analysis interval.

    - start_date (str) – The end point for predictions.

    - analysis_days (int) – How many days to analyze.

  for_eval: bool
  analysis_frequency: str
  start_date: str
  analysis_days: int
  __post_init__()

class abacusai.api_class.batch_prediction.ChatLLMBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the ChatLLM problem type

  Parameters:

    for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

  for_eval: bool
  __post_init__()

class abacusai.api_class.batch_prediction.TrainablePlugAndPlayBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the TrainablePlugAndPlay problem type

  Parameters:

    - for_eval (bool) – If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation.

    - create_monitor (bool) – Controls whether to automatically create a monitor to calculate the drift each time the batch prediction is run. Defaults to true if not specified.

  for_eval: bool
  create_monitor: bool
  __post_init__()

class abacusai.api_class.batch_prediction._BatchPredictionArgsFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'problem_type'
  config_class_map